@@ -1,8 +1,8 @@
-/* $Id: behaviour.js 374 2012-10-13 21:55:03Z pjf $ */
+/* $Id: behaviour.js 382 2012-10-28 23:52:22Z pjf $ */
 
 /* Local Variables:
- * Mode: javascript
- * Tab-width: 3
+ * mode: javascript
+ * tab-width: 3
  * End: */
 
 var Behaviour = new Class( {
@@ -11,6 +11,7 @@ var Behaviour = new Class( {
    config            : {
       anchors        : {},
       calendars      : {},
+      inputs         : {},
       lists          : {},
       scrollPins     : {},
       server         : {},
@@ -18,7 +19,8 @@ var Behaviour = new Class( {
       sliders        : {},
       spinners       : {},
       tables         : {},
-      tabSwappers    : {} },
+      tabSwappers    : {}
+   },
 
    options           : {
       contentId      : 'content',
@@ -32,6 +34,7 @@ var Behaviour = new Class( {
       minMarginLeft  : 0,
       minMarginRight : 10,
       popup          : false,
+      statusUpdPeriod: 5000,
       target         : null
    },
 
@@ -54,54 +57,41 @@ var Behaviour = new Class( {
    },
 
    load: function( first_field ) {
-      var cfg = this.config, el, opt = this.options;
+      var opt = this.options;
 
-      this.cookies = new Cookies( { domain: opt.cookieDomain,
-                                    path  : opt.cookiePath,
-                                    prefix: opt.cookiePrefix } );
-
-      this.stylesheet = new PersistantStyleSheet( { cookies: this.cookies } );
+      this.cookies     = new Cookies( {
+         domain        : opt.cookieDomain,
+         path          : opt.cookiePath,
+         prefix        : opt.cookiePrefix } );
+      this.stylesheet  = new PersistantStyleSheet( { cookies: this.cookies } );
 
       this._restoreStateFromCookie();
 
       this.submit      = new SubmitUtils( {
          context       : this,
-         config        : cfg.anchors,
          formName      : opt.formName } );
       this.window      = new WindowUtils( {
          context       : this,
-         config        : cfg.anchors,
          target        : opt.target,
          url           : opt.defaultURL } );
 
       this.autosizer   = new AutoSize( { context: this } );
-      this.calendars   = new Calendars( {
-         context       : this,
-         config        : cfg.calendars } );
+      this.calendars   = new Calendars( { context: this } );
       this.checkboxReplacements = new CheckboxReplace( { context: this } );
       this.freeList    = new FreeList( { context: this } );
       this.groupMember = new GroupMember( { context: this } );
       this.liveGrids   = new LiveGrids( {
          context       : this,
-         config        : cfg.anchors,
          iconClasses   : opt.iconClasses,
          url           : opt.defaultURL } );
-      this.rotateList  = new RotateList( {
-         context       : this,
-         config        : cfg.lists } );
+      this.noticeBoard = new NoticeBoard( { context: this } );
+      this.rotateList  = new RotateList( { context: this } );
       this.server      = new ServerUtils( {
          context       : this,
-         config        : cfg.server,
          url           : opt.defaultURL } );
-      this.sidebar     = new Sidebar ( {
-         context       : this,
-         config        : cfg.sidebars } );
-      this.sliders     = new Sliders( {
-         context       : this,
-         config        : cfg.sliders } );
-      this.spinners    = new Spinners( {
-         context       : this,
-         config        : cfg.spinners } );
+      this.sidebar     = new Sidebar ( { context: this } );
+      this.sliders     = new Sliders( { context: this } );
+      this.spinners    = new Spinners( { context: this } );
 
       var table_rebuild = function() {
          this.checkboxReplacements.build();
@@ -109,18 +99,13 @@ var Behaviour = new Class( {
 
       this.tables      = new TableUtils( {
          context       : this,
-         config        : cfg.tables,
          formName      : opt.formName,
          onRowAdded    : table_rebuild } );
       this.tableSort   = new TableSort( {
          context       : this,
          onSortComplete: table_rebuild } );
-      this.tabSwappers = new TabSwappers( {
-         context       : this,
-         config        : cfg.tabSwappers } );
-      this.togglers    = new Togglers( {
-         context       : this,
-         config        : cfg.anchors } );
+      this.tabSwappers = new TabSwappers( { context: this } );
+      this.togglers    = new Togglers( { context: this } );
       this.trees       = new Trees( {
          context       : this,
          cookieDomain  : opt.cookieDomain,
@@ -139,7 +124,7 @@ var Behaviour = new Class( {
 
       this.columnizers = new Columnizers( { context: this } );
       this.scrollPins  = new ScrollPins( {
-         config        : cfg.scrollPins,
+         context       : this,
          log           : this.window.log,
          onAttach      : function( el ) {
             this.addEvent( 'build', function() {
@@ -147,12 +132,10 @@ var Behaviour = new Class( {
             }.bind( el.pin.markup ) );
 
             this.addEvent( 'show', function() {
-               this.tween( 'opacity', 1 ) }.bind( el.pin.markup ) );
-         },
+               this.tween( 'opacity', 1 ) }.bind( el.pin.markup ) ); },
          onInitialize  : function() {
             this.fireEvent.delay( 1000, this, [ 'show' ] ) },
-         trayPadding   : 0
-      } );
+         trayPadding   : 0 } );
       this.tips        = new Tips( {
          context       : this,
          onHide        : function() { this.fx.start( 0 ) },
@@ -162,7 +145,10 @@ var Behaviour = new Class( {
          onShow        : function() { this.fx.start( 1 ) },
          showDelay     : 666 } );
 
-      if (first_field && (el = $( first_field ))) el.focus();
+      if (opt.statusUpdPeriod && !opt.popup)
+         this.statusUpdater.periodical( opt.statusUpdPeriod, this );
+
+      var el; if (first_field && (el = $( first_field ))) el.focus();
    },
 
    rebuild: function() {
@@ -174,7 +160,6 @@ var Behaviour = new Class( {
 
       if (! opt.popup) {
          this.cookies.set( 'height', h ); this.cookies.set( 'width',  w );
-         window.defaultStatus = 'w: ' + w + ' h: ' + h;
       }
 
       var content; if (! (content = $( opt.contentId ))) return;
@@ -228,5 +213,13 @@ var Behaviour = new Class( {
          /* Restore the source URL for elements whose ids end in Img */
          if (el = $( p0 + 'Img'  )) { if (p1) el.src = p1; }
       }
+   },
+
+   statusUpdater: function() {
+      var h = window.getHeight(), w = window.getWidth();
+
+      var swatch_time = Date.swatchTime();
+
+      window.defaultStatus = 'w: ' + w + ' h: ' + h + ' @' + swatch_time;
    }
 } );
